==> japhar-0.06.tar.gz: japhar-0.06/lib/libnative/sun.awt.motif/checkbox.c <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   checkbox.c -- native methods for sun/awt/motif/MCheckboxPeer..
   Created: Chris Toshok <toshok@hungry.com>, 14-Sep-1998.
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1998 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */

#include "jni.h"

#include "common.h"
#include <Xm/Xm.h>
#include <Xm/ToggleB.h>

#include <assert.h>
#include <stdlib.h>

JNIEXPORT void JNICALL
Java_sun_awt_motif_MCheckboxPeer_create(JNIEnv *env,
					jobject peer,
					jobject parent_peer)
{
  Widget checkbox;
  Widget parent;

  printf ("In Java_sun_awt_motif_MCheckboxPeer_create\n");

  assert(NULL != peer && NULL != parent_peer);

  parent = get_component_widget(env, parent_peer);

  LOCK_AWT();

  checkbox = XmCreateToggleButton(parent,
				  "checkbox",
				  NULL, 0);

  UNLOCK_AWT();

  set_component_widget(env, peer, checkbox);
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MCheckboxPeer_setLabel(JNIEnv *env,
					  jobject peer,
					  jstring text)
{
  Widget widget = get_component_widget(env, peer);
  const jbyte *label_text = (*env)->GetStringUTFChars(env, text, NULL);
  XmString label_xmstring;

  printf ("In Java_sun_awt_motif_MCheckboxPeer_setLabel\n");

  LOCK_AWT();

  label_xmstring = XmStringCreate((char*)label_text, XmFONTLIST_DEFAULT_TAG);
  XtVaSetValues(widget,
		XmNlabelString, label_xmstring,
		NULL);

  XmStringFree(label_xmstring);

  UNLOCK_AWT();

  (*env)->ReleaseStringUTFChars(env, text, label_text);
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MCheckboxPeer_setState(JNIEnv *env,
					  jobject peer,
					  jboolean state)
{
  Widget widget = get_component_widget(env, peer);

  XmToggleButtonSetState(widget, state, False);
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MCheckboxPeer_setCheckboxGroup(JNIEnv *env,
						  jobject peer,
						  jobject checkboxgroup)
{
}

==> japhar-0.07.tar.gz: japhar-0.07/lib/libnative/sun.awt.motif/checkbox.c <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   checkbox.c -- native methods for sun/awt/motif/MCheckboxPeer..
   Created: Chris Toshok <toshok@hungry.com>, 14-Sep-1998.
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1998 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
#include "config.h"

#include "jni.h"
#include "log.h"

#include "common.h"
#include <Xm/Xm.h>
#include <Xm/ToggleB.h>

#include <assert.h>
#include <stdlib.h>

JNIEXPORT void JNICALL
Java_sun_awt_motif_MCheckboxPeer_create(JNIEnv *env,
					jobject peer,
					jobject parent_peer)
{
  Widget checkbox;
  Widget parent;

  JAVARLOG0 (AWT_LOG, 2, "In Java_sun_awt_motif_MCheckboxPeer_create\n");

  assert(NULL != peer && NULL != parent_peer);

  parent = get_component_widget(env, parent_peer);

  LOCK_AWT();

  checkbox = XmCreateToggleButton(parent,
				  "checkbox",
				  NULL, 0);

  inherit_background_from(parent, checkbox);

  UNLOCK_AWT();

  set_component_widget(env, peer, checkbox);
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MCheckboxPeer_setLabel(JNIEnv *env,
					  jobject peer,
					  jstring text)
{
  Widget widget = get_component_widget(env, peer);
  const jbyte *label_text = (*env)->GetStringUTFChars(env, text, NULL);
  XmString label_xmstring;

  JAVARLOG0 (AWT_LOG, 2, "In Java_sun_awt_motif_MCheckboxPeer_setLabel\n");

  LOCK_AWT();

  label_xmstring = XmStringCreate((char*)label_text, XmFONTLIST_DEFAULT_TAG);
  XtVaSetValues(widget,
		XmNlabelString, label_xmstring,
		NULL);

  XmStringFree(label_xmstring);

  UNLOCK_AWT();

  (*env)->ReleaseStringUTFChars(env, text, label_text);
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MCheckboxPeer_setState(JNIEnv *env,
					  jobject peer,
					  jboolean state)
{
  Widget widget = get_component_widget(env, peer);

  LOCK_AWT();
  XmToggleButtonSetState(widget, state, False);
  UNLOCK_AWT();
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MCheckboxPeer_setCheckboxGroup(JNIEnv *env,
						  jobject peer,
						  jobject checkboxgroup)
{
}
